package
Version:
v0.0.0-...-6a35e63
Opens a new window with list of versions in this module.
Published: Mar 25, 2020
License: GPL-3.0
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Handler interface {
RegisterRoutes(router *mux.Router)
}
Handler is a contract to every handler that want to be included in the apps
Server hold mux Router and information of host port and address of our app
NewServer create Server from Handler
CreateHTTPServer will return http.Server for flexible use like testing
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.